==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextPaneUI.h <==
// public class javax.swing.plaf.basic.BasicTextPaneUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class 4442aa5b24bf8bad javax_swing_plaf_basic_BasicEditorPaneUI
// @dep_class 2c6b8ff29846f14d javax_swing_plaf_basic_BasicTextPaneUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicEditorPaneUI

#include "javax/swing/plaf/basic/BasicEditorPaneUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextPaneUI_H_
#define _JC_javax_swing_plaf_basic_BasicTextPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$refs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object	_jc_javax_swing_plaf_basic_BasicTextPaneUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *);

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicTextPaneUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicTextPaneUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextPaneUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextPaneUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicTextPaneUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicEditorPaneUI$vmethods	javax_swing_plaf_basic_BasicEditorPaneUI;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods	javax_swing_plaf_basic_BasicTextPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$refs {
    _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs	javax_swing_plaf_basic_BasicTextPaneUI;
    _jc_javax_swing_plaf_basic_BasicEditorPaneUI$sub_refs	javax_swing_plaf_basic_BasicEditorPaneUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicEditorPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicEditorPaneUI;
    _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object {
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype _jc_javax_swing_plaf_basic_BasicTextPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextPaneUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextPaneUI.h <==
// public class javax.swing.plaf.basic.BasicTextPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class 4442aa5b24bf8bad javax_swing_plaf_basic_BasicEditorPaneUI
// @dep_class 2c6b8ff29846f14d javax_swing_plaf_basic_BasicTextPaneUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicEditorPaneUI

#include "javax/swing/plaf/basic/BasicEditorPaneUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextPaneUI_H_
#define _JC_javax_swing_plaf_basic_BasicTextPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$refs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object	_jc_javax_swing_plaf_basic_BasicTextPaneUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_View$object *_jc_javax_swing_plaf_basic_BasicTextPaneUI$method$create$cf4235120765a02e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicTextPaneUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextPaneUI$method_info$create$cf4235120765a02e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextPaneUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicTextPaneUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods {
	struct _jc_javax_swing_text_View$object	*(*create$cf4235120765a02e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicEditorPaneUI$vmethods	javax_swing_plaf_basic_BasicEditorPaneUI;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vmethods	javax_swing_plaf_basic_BasicTextPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$refs {
    _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_refs	javax_swing_plaf_basic_BasicTextPaneUI;
    _jc_javax_swing_plaf_basic_BasicEditorPaneUI$sub_refs	javax_swing_plaf_basic_BasicEditorPaneUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicEditorPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicEditorPaneUI;
    _jc_javax_swing_plaf_basic_BasicTextPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextPaneUI$object {
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextPaneUI$vtype _jc_javax_swing_plaf_basic_BasicTextPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextPaneUI_H_ */
